#ifndef SOUND_H
#define SOUND_H

#include <QString>
#include <QObject>

#if QT_VERSION > 0x050000

#include <QtMultimedia>
#include <QTimer>
#include <QSound>
#include <QFile>

class Sound:public QObject
{
   Q_OBJECT
public:
   Sound(const QString& sound_file);
   Sound(QObject *parent, const QString& sound_file);
   ~Sound();
public slots:
   void play();
   void stop();
private:
   QSound *mSound;
};

#else

#include <phonon/audiooutput.h>
#include <phonon/mediaobject.h>
#include <QTimer>

class Sound:public QObject
{
   Q_OBJECT
public:
   Sound(QString sound_file);
   void set_loop_delay(int);
   int get_loop_delay();
public slots:
   void play();
   void stop();
   void loop();
private slots:
   void finished();
   void timer_timeout();
private:
   Phonon::AudioOutput *audioOutput;
   Phonon::MediaObject *mediaObject;
   Phonon::Path audiograph;
   Phonon::MediaSource source;
   Phonon::State oldstate;
   Phonon::State newstate;
   bool _loop;
   int _delay;
   QTimer loop_timer;


};


#endif


#endif



